@@ -6,7 +6,7 @@ eval 'exec perl -S $0 "$@"'
 
 pflogsumm.pl - Produce Postfix MTA logfile summary
 
-Copyright (C) 1998-2007 by James S. Seymour, Release 1.1.1.
+Copyright (C) 1998-2007 by James S. Seymour, Release 1.1.2.
 
 =head1 SYNOPSIS
 
@@ -363,7 +363,7 @@ eval { require Date::Calc };
 my $hasDateCalc = $@ ? 0 : 1;
 
 my $mailqCmd = "mailq";
-my $release = "1.1.1";
+my $release = "1.1.2";
 
 # Variables and constants used throughout pflogsumm
 use vars qw(
@@ -840,7 +840,7 @@ if(defined($dateStr)) {
     print "Postfix log summaries for $dateStr\n";
 }
 
-print "\nGrand Totals\n------------\n";
+print_subsect_title("Grand Totals");
 print "messages\n\n";
 printf " %6d%s  received\n", adj_int_units($msgsRcvd);
 printf " %6d%s  delivered\n", adj_int_units($msgsDlvrd);
@@ -926,7 +926,7 @@ sub print_problems_reports {
 if($opts{'mailq'}) {
     # flush stdout first cuz of asynchronousity
     $| = 1;
-    print "\nCurrent Mail Queue\n------------------\n";
+    print_subsect_title("Current Mail Queue");
     system($mailqCmd);
 }
 
@@ -935,9 +935,10 @@ if($opts{'mailq'}) {
 sub print_per_day_summary {
     my($msgsPerDay) = @_;
     my $value;
-    print <<End_Of_Per_Day_Heading;
 
-Per-Day Traffic Summary
+    print_subsect_title("Per-Day Traffic Summary");
+
+    print <<End_Of_Per_Day_Heading;
     date          received  delivered   deferred    bounced     rejected
     --------------------------------------------------------------------
 End_Of_Per_Day_Heading
@@ -964,9 +965,10 @@ sub print_per_hour_summary {
     my ($rcvPerHr, $dlvPerHr, $dfrPerHr, $bncPerHr, $rejPerHr, $dayCnt) = @_;
     my $reportType = $dayCnt > 1? 'Daily Average' : 'Summary';
     my ($hour, $value);
-    print <<End_Of_Per_Hour_Heading;
 
-Per-Hour Traffic $reportType
+    print_subsect_title("Per-Hour Traffic $reportType");
+
+    print <<End_Of_Per_Hour_Heading;
     time          received  delivered   deferred    bounced     rejected
     --------------------------------------------------------------------
 End_Of_Per_Hour_Heading
@@ -998,9 +1000,10 @@ sub print_recip_domain_summary {
     return if($cnt == 0);
     my $topCnt = $cnt > 0? "(top $cnt)" : "";
     my $avgDly;
-    print <<End_Of_Recip_Domain_Heading;
 
-Host/Domain Summary: Message Delivery $topCnt
+    print_subsect_title("Host/Domain Summary: Message Delivery $topCnt");
+
+    print <<End_Of_Recip_Domain_Heading;
  sent cnt  bytes   defers   avg dly max dly host/domain
  -------- -------  -------  ------- ------- -----------
 End_Of_Recip_Domain_Heading
@@ -1032,9 +1035,10 @@ sub print_sending_domain_summary {
     my($cnt) = $_[1];
     return if($cnt == 0);
     my $topCnt = $cnt > 0? "(top $cnt)" : "";
-    print <<End_Of_Sender_Domain_Heading;
 
-Host/Domain Summary: Messages Received $topCnt
+    print_subsect_title("Host/Domain Summary: Messages Received $topCnt");
+
+    print <<End_Of_Sender_Domain_Heading;
  msg cnt   bytes   host/domain
  -------- -------  -----------
 End_Of_Sender_Domain_Heading
@@ -1079,16 +1083,16 @@ sub print_per_hour_smtpd {
     my ($smtpdPerHr, $dayCnt) = @_;
     my ($hour, $value);
     if($dayCnt > 1) {
-	print <<End_Of_Per_Hour_Smtp_Average;
+	print_subsect_title("Per-Hour SMTPD Connection Daily Average");
 
-Per-Hour SMTPD Connection Daily Average
+	print <<End_Of_Per_Hour_Smtp_Average;
     hour        connections    time conn.
     -------------------------------------
 End_Of_Per_Hour_Smtp_Average
     } else {
-	print <<End_Of_Per_Hour_Smtp;
+	print_subsect_title("Per-Hour SMTPD Connection Summary");
 
-Per-Hour SMTPD Connection Summary
+	print <<End_Of_Per_Hour_Smtp;
     hour        connections    time conn.    avg./conn.   max. time
     --------------------------------------------------------------------
 End_Of_Per_Hour_Smtp
@@ -1127,9 +1131,10 @@ End_Of_Per_Hour_Smtp
 # (done in a subroutine only to keep main-line code clean)
 sub print_per_day_smtpd {
     my ($smtpdPerDay, $dayCnt) = @_;
-    print <<End_Of_Per_Day_Smtp;
 
-Per-Day SMTPD Connection Summary
+    print_subsect_title("Per-Day SMTPD Connection Summary");
+
+    print <<End_Of_Per_Day_Smtp;
     date        connections    time conn.    avg./conn.   max. time
     --------------------------------------------------------------------
 End_Of_Per_Day_Smtp
@@ -1163,9 +1168,10 @@ sub print_domain_smtpd_summary {
     return if($cnt == 0);
     my $topCnt = $cnt > 0? "(top $cnt)" : "";
     my $avgDly;
-    print <<End_Of_Domain_Smtp_Heading;
 
-Host/Domain Summary: SMTPD Connections $topCnt
+    print_subsect_title("Host/Domain Summary: SMTPD Connections $topCnt");
+
+    print <<End_Of_Domain_Smtp_Heading;
  connections  time conn.  avg./conn.  max. time  host/domain
  -----------  ----------  ----------  ---------  -----------
 End_Of_Domain_Smtp_Heading
@@ -1299,6 +1305,12 @@ sub really_print_hash_by_cnt_vals {
     }
 }
 
+# Print a sub-section title with properly-sized underline
+sub print_subsect_title {
+    my $title = $_[0];
+    print "\n$title\n" . "-" x length($title) . "\n";
+}
+
 # Normalize IP addr or hostname
 # (Note: Makes no effort to normalize IPv6 addrs.  Just returns them
 # as they're passed-in.)
@@ -1388,11 +1400,11 @@ sub by_count_then_size {
 sub get_datestr {
     my $dateOpt = $_[0];
 
-    my $aDay = 60 * 60 * 24;
-
     my $time = time();
+
     if($dateOpt eq "yesterday") {
-	$time -= $aDay;
+	# Back up to yesterday
+	$time -= ((localtime($time))[2] + 2) * 3600;
     } elsif($dateOpt ne "today") {
 	die "$usageMsg\n";
     }
